import { Loader } from "@googlemaps/js-api-loader";
const RETRIES = Number("<%= options.retries %>");
let loader = null;
function _isTrue(val) {
    return val === "true";
}
async function loadGoogleMaps(name = "places", language, region) {
    if (!language && _isTrue("<%= options.i18n %>")) {
        language = window.$nuxt.$i18n.locale;
    }
    loader = new Loader({
        apiKey: "<%= options.apiKey %>",
        language: language,
        region: region,
        version: "quarterly",
        libraries: ["places"],
        retries: RETRIES,
    });
    try {
        await loader.importLibrary(name);
    }
    catch (err) {
        return false;
    }
    return true;
}
// Returns a Promise that resolves to google.maps or undefined if destroyed or not loaded
export async function getGoogleMapsInstance(arg) {
    if (arg === "destroy") {
        if (loader) {
            loader.deleteScript();
        }
        window.gm_authFailure = undefined;
        window.google = undefined;
        loader = null;
        const scripts = document.querySelectorAll('script[src*="maps.googleapis.com"]');
        scripts.forEach((script) => script.remove());
        return null;
    }
    if (!loader || !window.google?.maps) {
        const isLoaded = await loadGoogleMaps(arg?.name, arg?.language, arg?.region);
        if (!isLoaded) {
            throw new Error(`nuxt-maps: Failed to load google maps library after ${RETRIES} retries`);
        }
    }
    return window.google?.maps[arg?.name ?? "places"] ?? null;
}
const googleMapsPlugin = (_, inject) => {
    inject("gmaps", getGoogleMapsInstance);
};
export default googleMapsPlugin;
//# sourceMappingURL=plugin.js.map